==> sms_ippanel-7.x-1.0.tar.gz: sms_ippanel/sms_ippanel.js <==
(function($){
	$(document).ready(function(){
    $('#sms-ippanel-sender-form textarea#edit-message').after('<div><span id="pattern-wizard">ابزار تنظیم پترن</span><div id="panel-modal"></div>');
	$("#pattern-wizard").click(function(){
		$('#panel-modal').show(500);
		var targettextarea = $(this).parents('.form-textarea-wrapper').find('textarea');
		modalbody = '<div id="onlinepattern"><div class="form-group"><label>کد الگو:</label><input class="patterncodeinput form-control" placeholder="کد الگوی مورد نظر خود را وارد نمایید" ><button class="btn btn-default onlinepcodechecker" type="button">بررسی الگو</button></div><div class="pattern-message"></div><div class="pcodecheckresult"></div><div><button class="btn btn-default patterninsert hidden" type="button">ثبت الگو در کادر پیامک</button></div></div><div id="helppattern"><p><b>راهنما:</b> برای استفاده از سیستم پترن برای ارسال سریع پیامک باید یک متن پیامک به دلخواه خود در سامانه پیامک ثبت کنید.</p> پس از ثبت و تایید پترن از بخش تنظیم پترن به صورت آنلاین کد پترن را درج و متغیرهای هر پارامتر را وارد نمایید.</div>';
			
		$('#panel-modal').html(modalbody);
		$('.onlinepcodechecker').click(function(){
		
			pcode = $('#onlinepattern .patterncodeinput').val();
			var query = $.ajax({
				type: 'POST',
				url: '/admin/ajax/checkcode',
				data: 'method=patterncodechecker&pcode=' + pcode,
				dataType: 'json',
				beforeSend: function(){
					$('#onlinepattern .pattern-message').html('<i class="process-icon-loading"></i>');
				},
				success: function(json) {
				  if(json.status == 0){
					$('#onlinepattern .pattern-message').html(json.message.replace("\n","<br>"));
					var pvars = json.vars;
					var output = '<p>لطفاً پارامترهای پترن را با متغیرهای سایت تکمیل نمایید.</p>';
					pvars.forEach(function(value, index, array){
						output += '<div><label>'+value+'</label><input type="text"/></div>';
					});
					$('#onlinepattern .pcodecheckresult').html(output);
					$('#onlinepattern .variableshelp,#onlinepattern .patterninsert').removeClass('hidden');
					$('.onlinepcodechecker').addClass('hidden');
					var patternoutput = 'pcode:'+pcode;
					$('#onlinepattern .patterninsert').click(function(){
						$('#onlinepattern .pcodecheckresult div').each(function(){
							patternoutput += "\n"+$(this).find('label').text()+':'+$(this).find('input').val();
						})
						targettextarea.html(patternoutput);
						$('#panel-modal').hide(500);
					});
				  }else if(json.status == 997 || json.status == 404){
					  $('#onlinepattern .pattern-message').html('این الگو در دسترس شما نیست.');
				  }
				}
			});
		});
	});
	});
})(jQuery);

==> sms_ippanel-7.x-1.4.tar.gz: sms_ippanel/sms_ippanel.js <==
(function($){
	$(document).ready(function(){
    $('#sms-ippanel-sender-form textarea#edit-message').after('<div><span id="pattern-wizard">ابزار تنظیم پترن</span><div id="panel-modal"></div>');
	$("#pattern-wizard").click(function(){
		$('#panel-modal').show(500);
		var targettextarea = $(this).parents('.form-textarea-wrapper').find('textarea');
		modalbody = '<div id="onlinepattern"><div class="form-group"><label>کد الگو:</label><input class="patterncodeinput form-control" placeholder="کد الگوی مورد نظر خود را وارد نمایید" ><button class="btn btn-default onlinepcodechecker" type="button">بررسی الگو</button></div><div class="pattern-message"></div><div class="pcodecheckresult"></div><div><button class="btn btn-default patterninsert hidden" type="button">ثبت الگو در کادر پیامک</button></div></div><div id="helppattern"><p><b>راهنما:</b> برای استفاده از سیستم پترن برای ارسال سریع پیامک باید یک متن پیامک به دلخواه خود در سامانه پیامک ثبت کنید.</p> پس از ثبت و تایید پترن از بخش تنظیم پترن به صورت آنلاین کد پترن را درج و متغیرهای هر پارامتر را وارد نمایید.</div>';
			
		$('#panel-modal').html(modalbody);
		$('.onlinepcodechecker').click(function(){
		
			pcode = $('#onlinepattern .patterncodeinput').val();
			var query = $.ajax({
				type: 'POST',
				url: '/admin/ajax/checkcode',
				data: 'method=patterncodechecker&pcode=' + pcode,
				dataType: 'json',
				beforeSend: function(){
					$('#onlinepattern .pattern-message').html('<i class="process-icon-loading"></i>');
				},
				success: function(json) {
				  if(json.status == 0){
					$('#onlinepattern .pattern-message').html(json.message.replace("\n","<br>"));
					var pvars = json.vars;
					var output = '<p>لطفاً پارامترهای پترن را با متغیرهای سایت تکمیل نمایید.</p>';
					pvars.forEach(function(value, index, array){
						output += '<div><label>'+value+'</label><input type="text"/></div>';
					});
					$('#onlinepattern .pcodecheckresult').html(output);
					$('#onlinepattern .variableshelp,#onlinepattern .patterninsert').removeClass('hidden');
					$('.onlinepcodechecker').addClass('hidden');
					var patternoutput = 'pcode:'+pcode.trim();
					$('#onlinepattern .patterninsert').click(function(){
						$('#onlinepattern .pcodecheckresult div').each(function(){
							patternoutput += "\n"+$(this).find('label').text()+':'+$(this).find('input').val().trim();
						})
						targettextarea.html(patternoutput);
						$('#panel-modal').hide(500);
					});
				  }else if(json.status == 997 || json.status == 404){
					  $('#onlinepattern .pattern-message').html('این الگو در دسترس شما نیست.');
				  }
				}
			});
		});
	});
	});
})(jQuery);
